package
Version:
v1.1.0
Opens a new window with list of versions in this module.
Published: Mar 31, 2026
License: GPL-3.0, MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Rendered for windows/amd64
Callbacks holds the pre-registered syscall callback addresses for a delegate's vtable.
Register associates an instance pointer with a Delegate and returns the vtable callbacks.
type Delegate interface {
GetIID() *winrt.GUID
Invoke(instancePtr, rawArgs0, rawArgs1, rawArgs2, rawArgs3, rawArgs4, rawArgs5, rawArgs6, rawArgs7, rawArgs8 unsafe.Pointer) uintptr
AddRef() uintptr
Release() uintptr
}
Delegate represents a WinRT delegate that can receive callbacks.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.