Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Class ¶
type Class struct {
Name string
Signature string
RequiredImports []*Import
FullyQualifiedName string
ImplInterfaces []*Interface
ExclusiveInterfaces []*Interface
HasEmptyConstructor bool
IsAbstract bool
}
Class represents a WinRT runtime class.
type Data ¶
type Data struct {
Package string
Imports []string
Classes []*Class
Enums []*Enum
Interfaces []*Interface
Structs []*Struct
Delegates []*Delegate
}
Data holds all types resolved for a single output file.
type DefaultValue ¶
DefaultValue holds the default value expression for a type.
type Delegate ¶
type Delegate struct {
Name string
GUID string
Signature string
InParams []*Param
ReturnParam *Param
}
Delegate represents a WinRT delegate type.
type Func ¶
type Func struct {
Name string
RequiredImports []*Import
Implement bool
FuncOwner string
InParams []*Param
ReturnParams []*Param
ExclusiveTo string
RequiresActivation bool
InheritedFrom QualifiedID
}
Func represents a WinRT method.
type Import ¶
type Import struct {
Namespace, Name string
}
Import represents a dependency on another WinRT namespace.
type Param ¶
Param represents a method parameter or struct field.
func (*Param) GoDefaultValue ¶
GoDefaultValue returns the Go zero/default expression for a parameter's type.
func (*Param) GoTypeName ¶
GoTypeName returns the Go type expression for a parameter.
type ParamType ¶
type ParamType struct {
Namespace string
Name string
IsPointer bool
IsGeneric bool
IsArray bool
IsPrimitive bool
IsEnum bool
UnderlyingEnumType string
DefaultValue DefaultValue
}
ParamType describes the type of a parameter.
type QualifiedID ¶
type QualifiedID struct {
Namespace, Name string
}
QualifiedID holds namespace and name of a qualified element.
Click to show internal directories.
Click to hide internal directories.